
-- SIDES curse: moves the block to the left or right --------------------

ID_CURSE_SIDES=18

function sides_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_SIDES)
    else
        if mod(floor(u61_get_time()/100),2)==0 then
            u61_set_block_x(0)
        else
            u61_set_block_x(u61_get_width());        
        end
    end
end

